//
//  CDDevice.h
//  CoreDevice
//
//  Created by Alex Cohen on 9/15/09.
//  Copyright 2009 Toomuchspace. All rights reserved.
//

#if defined(TARGET_OS_IPHONE) && TARGET_OS_IPHONE
#import <CDObject.h>
#else
#import <CoreDevice/CDObject.h>
#endif

@class CDDeviceCenter;
@class CDCommand;
@class CDCommandResponse;
@class CDReceipt;
@class NSImage;

@protocol CDDeviceDelegate;

@interface CDDevice : CDObject {
	CDDeviceCenter*			dc; // waek ref
	BOOL					cachedAvailability;
	NSMutableDictionary*	receiptSourceMap;
	NSMutableDictionary*	selectorSourceMap;
	NSArray*				delegates;
}

@property (readonly) BOOL isAvailable;
@property (readonly,copy) NSString* name;
@property (readonly,copy) NSString* displayName;
@property (readonly) BOOL isCalibrated;
@property (readonly) BOOL isCalibrating;
@property (copy) NSString* mode;
@property (readonly,copy) NSArray* modes;
@property (assign) BOOL enabled;
@property (readonly,copy) NSString* serialNumber;
@property (readonly) BOOL softwareMeasurementAvailable;
@property (readonly,copy) NSString* license;
@property (readonly,retain) NSImage* icon;

- (void)addDelegate:(id<CDDeviceDelegate>)aDelegate;
- (void)removeDelegate:(id<CDDeviceDelegate>)aDelegate;

- (NSString*)attributeForKey:(NSString*)key;
- (void)setAttribute:(NSString*)attribute forKey:(NSString*)key;

- (void)calibrate;
- (void)measure;

- (CDCommandResponse*)sendSynchronousCommand:(CDCommand*)cmd;
- (CDCommandResponse*)sendSynchronousCommandWithName:(NSString*)cmdName;

- (CDReceipt*)sendCommand:(CDCommand*)cmd;
- (CDReceipt*)sendCommandWithName:(NSString*)cmdName;

// response selector: - (void)device:(CDDevice*)device didReceiveResponse:(CDCommandResponse*)response;
- (void)sendCommand:(CDCommand *)cmd delegate:(id)delegate responseSelector:(SEL)aSelector;

@end

@protocol CDDeviceDelegate <NSObject>

@optional
- (void)deviceDidBeginCalibrating:(CDDevice*)device;
- (void)deviceDidFinishCalibrating:(CDDevice*)device;
- (void)device:(CDDevice*)device didFailToCalibrateWithError:(NSError*)error;

- (void)deviceDidBecomeAvailable:(CDDevice*)device;
- (void)deviceDidBecomeUnavailable:(CDDevice*)device;

- (void)deviceStatusDidChange:(CDDevice*)device;

- (void)device:(CDDevice*)device didReceiveResponse:(CDCommandResponse*)response;
- (void)device:(CDDevice*)device didReceiveError:(NSError*)error forCommand:(CDCommand*)command;

- (void)device:(CDDevice*)device didReceiveMeasurements:(NSArray*)measurements;

- (void)device:(CDDevice*)device didReceiveCommand:(CDCommand*)cmd;

@end



