//
//  CDDeviceCenter.h
//  CoreDevice
//
//  Created by Alex Cohen on 9/15/09.
//  Copyright 2009 Toomuchspace. All rights reserved.
//

#if defined(TARGET_OS_IPHONE) && TARGET_OS_IPHONE
#import <CDObject.h>
#else
#import <CoreDevice/CDObject.h>
#endif

@class CDDevice;
@class CDCommandResponse;
@protocol CDDeviceCenterDelegate;

@interface CDDeviceCenter : CDObject {
	NSMutableArray*					devices;
	NSMutableDictionary*			nameDeviceMap;
	NSRecursiveLock*				lock;
	NSArray*						delegates;
}

@property (retain,readonly) NSArray* devices;

+ (CDDeviceCenter*)defaultCenter;
+ (CDDeviceCenter*)centerWithType:(void*)center;
+ (CDDeviceCenter*)centerWithAddress:(NSString*)addr;

+ (void)setLogLevel:(NSUInteger)level;
+ (void)setLogFilename:(NSString*)filename;

- (void)addDelegate:(id<CDDeviceCenterDelegate>)aDelegate;
- (void)removeDelegate:(id<CDDeviceCenterDelegate>)aDelegate;

- (void)registerSourceName:(NSString*)sourceName;
- (void)registerSourceNameAsServer:(NSString*)sourceName;

- (CDDevice*)deviceWithName:(NSString*)deviceName;

@end


@protocol CDDeviceCenterDelegate <NSObject>

@optional
- (void)deviceCenter:(CDDeviceCenter*)dc deviceWasAdded:(CDDevice*)device;
- (void)deviceCenter:(CDDeviceCenter*)dc deviceWasRemoved:(CDDevice*)device;

- (void)deviceCenter:(CDDeviceCenter*)dc deviceStatusDidChage:(CDDevice*)device;
- (void)deviceCenter:(CDDeviceCenter*)dc didReceiveCommandResponse:(CDCommandResponse*)response;

@end

#ifdef __cplusplus
extern "C" {
#endif

extern void CDDeviceCenterLog( NSString* format, ... );
extern void CDDeviceCenterLogv( NSString* format, va_list args );

#ifdef __cplusplus
}
#endif

